<?php

/**
*
* @package Ban Users from Topic
* @copyright (c) 2016 www.phpbb-work.ru
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

namespace shredder\ban_users_from_topic\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class listener implements EventSubscriberInterface
{
	/** @var \phpbb\auth\auth */
	protected $auth;

	/** @var \phpbb\db\driver\driver_interface */
	protected $db;

	/** @var \phpbb\request\request */
	protected $request;

	/** @var \phpbb\template */
	protected $template;

	/** @var \phpbb\user */
	protected $user;

	/**
	* Constructor
	* 
	* @param \phpbb\template\template $template
	*/
	public function __construct(\phpbb\auth\auth $auth, \phpbb\db\driver\driver_interface $db, \phpbb\request\request $request, \phpbb\template\template $template, \phpbb\user $user)
	{
		$this->auth = $auth;
		$this->db = $db;
		$this->request = $request;
		$this->template = $template;
		$this->user = $user;
	}

	/**
	* Assign functions defined in this class to event listeners in the core
	*
	* @return array
	* @static
	* @access public
	*/
	static public function getSubscribedEvents()
	{
		return array(
			'core.mcp_topic_modify_post_data'		=> 'ban_users_from_topic_mcp',
			'core.posting_modify_submit_post_before'	=> 'deny_posting_for_banned_users',
		);
	}

	/**
	* Handle MCP control
	*/
	public function ban_users_from_topic_mcp($event)
	{
		$this->user->add_lang_ext('shredder/ban_users_from_topic', 'ban_users_from_topic');

		$sql = 'SELECT denied_reply_users
			FROM ' . TOPICS_TABLE . "
			WHERE topic_id = {$event['topic_id']}";
		$result = $this->db->sql_query($sql);
		$topic_info['denied_reply_users'] = $this->db->sql_fetchfield('denied_reply_users');
		$this->db->sql_freeresult($result);

		$deny_reply = $this->request->is_set('deny_reply', \phpbb\request\request_interface::POST);
		$denied_reply_users = $this->request->variable('denied_reply_users', $topic_info['denied_reply_users'], false, \phpbb\request\request_interface::POST);

		if ($deny_reply)
		{
			$denied_reply_users = explode(',', $denied_reply_users);
			$denied_reply_users = array_map('intval', $denied_reply_users);
			$denied_reply_users = implode(',', $denied_reply_users);

			$sql = 'UPDATE ' . TOPICS_TABLE . "
				SET denied_reply_users = '" . $this->db->sql_escape($denied_reply_users) . "'
				WHERE topic_id = {$event['topic_id']}";
			$this->db->sql_query($sql);
		}

		$this->template->assign_var('DENIED_REPLY_USERS', $denied_reply_users);
	}

	/**
	* Deny posting for banned users
	*/
	public function deny_posting_for_banned_users($event)
	{
		if ($event['mode'] != 'post' && $event['post_data']['denied_reply_users'])
		{
			$denied_reply_users = explode(',', $event['post_data']['denied_reply_users']);

			if (in_array($this->user->data['user_id'], $denied_reply_users))
			{
				$this->user->add_lang_ext('shredder/ban_users_from_topic', 'ban_users_from_topic');

				trigger_error('DENIED_REPLY');
			}
		}
	}

	public function seo_return($event)
	{
		return;

		if (!defined('PHPBB_WORK_INFO'))
		{
			$this->template->assign_vars(array(
				'PHPBB_WORK_TOPIC_BAN'	=> ($this->config['default_lang'] == 'ru') ? true : false,
			));

			define('PHPBB_WORK_INFO', 1);
		}
	}
}
